Package: MRgrowth
Type: Package
Title: Mark-Recapture Growth Models
Version: 0.1.2
Authors@R: person(
    given = c("Donald", "T."),
    family = "McKnight",
    role = c("aut", "cre"),
    email = "donald.mcknight@my.jcu.edu.au",
    comment = c(affiliation = "Savanna Field Station"))
Date: 2026-04-06
Maintainer: Donald T. McKnight <donald.mcknight@my.jcu.edu.au>
Description: Researchers often need to calculate body-size growth rates for individuals
    that do not have associated age data. These growth rates are based on
    mark-recapture data where an individual was captured and measured at time 1
    then recaptured and measured at time 2. The sizes at each time and amount
    of time between captures can be used to calculate growth rates. 'MRgrowth'
    follows the approach in Edmonds et al. (2021) <doi:10.1371/journal.pone.0259978>
    and provides functions to calculate growth using three formulas, the
    Faben's reformulation of the von Bertalanffy formula, the Gompertz 
    formula, and a logistic formula.
License: GPL (>= 3)
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.3
Suggests: knitr,rmarkdown
Depends: R (>= 3.5)
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-04-06 23:11:29 UTC; Donald McKnight
Author: Donald T. McKnight [aut, cre] (affiliation: Savanna Field Station)
Repository: CRAN
Date/Publication: 2026-04-10 14:20:07 UTC
Built: R 4.5.2; ; 2026-04-15 04:55:52 UTC; unix
