export(age.at.size)
export(size.at.age)
export(calc.growth)
export(format.data)
export(logistic)
export(gompertz)
export(vb)
importFrom("grDevices", "adjustcolor")
importFrom("graphics", "legend", "lines", "polygon")
importFrom("stats", "dnorm", "median", "na.omit", "optim", "quantile", "setNames")
