% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/size.at.age.R
\name{size.at.age}
\alias{size.at.age}
\title{Size at age}
\usage{
size.at.age(A, k, age, size0, model)
}
\arguments{
\item{A}{(numeric) Asymptotic body size (can be calculated in \code{calc.growth()})}

\item{k}{(numeric) Growth rate (can be calculated in \code{calc.growth()})}

\item{age}{(numeric vector) The age(s) for which you want to know the size (should be in the same units used to calculate A and k)}

\item{size0}{(numeric) Initial body size at birth/hatching (should be in the same units used to calculate A and k). This will generally be a species average, rather than being specific per individual, but it can be a vector of specific birth/hatching sizes per individual if known.}

\item{model}{(character) The model used to calculate A and k. One of "vb", "gompertz","logistic".}
}
\value{
Vector of expected size(s)
}
\description{
Calculate expected size at a given age
}
\details{
It takes a vector of ages, initial size for the species, and A and k from \code{calc.growth()} and returns the expected body sizes at a given age based on the specified model.
}
\examples{
#For this example, assume size is in mm and time is in years
#Use the gompertz formula to calculate the expected size of a 5-year old
#turtle for a species that hatches at an average size of 50 mm
size.at.age(A = 396.6738,
 k = 0.2029850,
 age = 5,
 size0 = 50,
 model="gompertz")

}
