% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/MRdata.R
\docType{data}
\name{MRdata}
\alias{MRdata}
\title{Example mark-recapture data set}
\format{
A data frame with 43 rows and 3 variables:
\describe{
  \item{id}{Unique ID for each individual}
  \item{size}{Individual body size at each capture}
  \item{date}{Date of each measrement in Date format}
}
}
\source{
Hypothetical data over 2-3 capture events
}
\usage{
data(MRdata)
}
\description{
Example mark-recapture data set of male and female turtles from two populations
}
\keyword{datasets}
