% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gompertz.R
\name{gompertz}
\alias{gompertz}
\title{Gompertz growth}
\usage{
gompertz(A, k, size1, td)
}
\arguments{
\item{A}{(numeric) Asymptotic body size (can be calculated in \code{calc.growth()})}

\item{k}{(numeric) Growth rate (can be calculated in \code{calc.growth()})}

\item{size1}{(numeric vector) Initial body size (should be in the same units used to calculate A and k)}

\item{td}{(numeric vector) Time since \code{size1} (should be in the same units used to calculate A and k)}
}
\value{
Vector of expected size(s) after the time interval(s) specified in \code{td}
}
\description{
Calculate size after a given time interval using Gompertz formula
}
\details{
It takes a vector of initial sizes, vector of amounts of time since those sizes were measured, and A and k from \code{calc.growth(model="gompertz")} and returns the expected body sizes after the specified time intervals.

\strong{Note}: If size1 > A, the resulting size estimate will be less than size1
}
\examples{
#For this example, assume size is in mm and time is in years
#calculate expected sizes of individuals that are 200 and 300 mm after 2 and 1.5 years, respectively
gompertz(A = 396.6738,
 k = 0.2029850,
 size1 = c(200,300),
 td = c(2,1.5))

}
\references{
Gompertz, B. (1833). On the nature of the function expressive of the law of human
mortality, and on a new mode of determining the value of life contingencies.
\emph{Philosophical Transactions of the Royal Society of London}, 123, 252-253.
}
